summaryrefslogtreecommitdiffstats
path: root/kmymoney2/widgets/kmymoneyaccounttreeforecast.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/widgets/kmymoneyaccounttreeforecast.h')
-rw-r--r--kmymoney2/widgets/kmymoneyaccounttreeforecast.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/kmymoney2/widgets/kmymoneyaccounttreeforecast.h b/kmymoney2/widgets/kmymoneyaccounttreeforecast.h
index 5f3cd85..1f4199b 100644
--- a/kmymoney2/widgets/kmymoneyaccounttreeforecast.h
+++ b/kmymoney2/widgets/kmymoneyaccounttreeforecast.h
@@ -41,7 +41,7 @@ class KMyMoneyAccountTreeForecast : public KMyMoneyAccountTreeBase
Q_OBJECT
TQ_OBJECT
public:
- KMyMoneyAccountTreeForecast(TQWidget* tqparent = 0, const char *name = 0);
+ KMyMoneyAccountTreeForecast(TQWidget* parent = 0, const char *name = 0);
virtual ~KMyMoneyAccountTreeForecast() {}
void showSummary(MyMoneyForecast& forecast);
@@ -66,7 +66,7 @@ public:
* Constructor to be used to construct an account
* entry object for a forecast.
*
* @param tqparent pointer to the tqparent KAccountListView object this entry should be
* added to.
* @param account const reference to MyMoneyAccount for which
* the KListView entry is constructed
@@ -77,13 +77,13 @@ public:
* @param security const reference to the security used to show the value. Usually
* one should pass MyMoneyFile::baseCurrency() here.
*/
- KMyMoneyAccountTreeForecastItem(KMyMoneyAccountTreeForecastItem *tqparent, const MyMoneyAccount& account, const MyMoneyForecast& forecast, const TQValueList<MyMoneyPrice>& price = TQValueList<MyMoneyPrice>(), const MyMoneySecurity& security = MyMoneySecurity(), const EForecastViewType forecastViewType = eUndefined);
+ KMyMoneyAccountTreeForecastItem(KMyMoneyAccountTreeForecastItem *parent, const MyMoneyAccount& account, const MyMoneyForecast& forecast, const TQValueList<MyMoneyPrice>& price = TQValueList<MyMoneyPrice>(), const MyMoneySecurity& security = MyMoneySecurity(), const EForecastViewType forecastViewType = eUndefined);
/**
* Constructor to be used to construct an account
* entry object for a forecast.
*
* @param tqparent pointer to the tqparent KAccountListView object this entry should be
* added to.
* @param account const reference to MyMoneyAccount for which
* the KListView entry is constructed
@@ -94,7 +94,7 @@ public:
* @param name name of the account to be used instead of the one stored with @p account
* If empty, the one stored with @p account will be used. Default: empty
*/
- KMyMoneyAccountTreeForecastItem(KListView *tqparent, const MyMoneyAccount& account, const MyMoneyForecast &forecast, const MyMoneySecurity& security = MyMoneySecurity(), const TQString& name = TQString());
+ KMyMoneyAccountTreeForecastItem(KListView *parent, const MyMoneyAccount& account, const MyMoneyForecast &forecast, const MyMoneySecurity& security = MyMoneySecurity(), const TQString& name = TQString());
~KMyMoneyAccountTreeForecastItem();
@@ -66,7 +66,7 @@ public:
* entry object for a forecast.
*
- * @param tqparent pointer to the tqparent KAccountListView object this entry should be
+ * @param parent pointer to the parent KAccountListView object this entry should be
* added to.
* @param account const reference to MyMoneyAccount for which
@@ -77,13 +77,13 @@ public:
* entry object for a forecast.
*
- * @param tqparent pointer to the tqparent KAccountListView object this entry should be
+ * @param parent pointer to the parent KAccountListView object this entry should be
* added to.
* @param account const reference to MyMoneyAccount for which